==> fizmo-0.8.1.tar.gz: fizmo-0.8.1/fizmo-ncursesw/src/locales/fizmo_ncursesw_locales.h <==

/* fizmo_ncursesw_locales.h
 *
 * This file is part of fizmo.
 *
 * Copyright (c) 2009-2016 Christoph Ender.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef fizmo_ncursesw_locales_h_INCLUDED
#define fizmo_ncursesw_locales_h_INCLUDED

#define i18n_ncursesw_SET_FOREGROUND_COLOR 0
#define i18n_ncursesw_SET_BACKGROUND_COLOR 1
#define i18n_ncursesw_SET_LEFT_MARGIN_SIZE 2
#define i18n_ncursesw_SET_RIGHT_MARGIN_SIZE 3
#define i18n_ncursesw_INVALID_CONFIGURATION_VALUE_P0S_FOR_P1S 4
#define i18n_ncursesw_USAGE_DESCRIPTION 5
#define i18n_ncursesw_VALID_OPTIONS_ARE 6
#define i18n_ncursesw_SET_LOCALE_NAME_FOR_INTERPRETER_MESSAGES 7
#define i18n_ncursesw_START_WITH_RANDOM_GENERATOR_IN_PREDICTABLE_MODE 8
#define i18n_ncursesw_START_GAME_WITH_TRANSCRIPT_ENABLED 9
#define i18n_ncursesw_LIBFIZMO_VERSION_P0S 10
#define i18n_ncursesw_LOCALES_AVAILIABLE 11
#define i18n_ncursesw_MORE_PROMPT 12
#define i18n_ncursesw_SCORE 13
#define i18n_ncursesw_TURNS 14
#define i18n_ncursesw_NUMBER_OF_COLOR_COMBINATIONS_AVAILABLE_P0D 15
#define i18n_ncursesw_COLORS_AVAILABLE 16
#define i18n_ncursesw_INVALID_COLOR_NAME 17
#define i18n_ncursesw_SHOW_HELP_MESSAGE_AND_EXIT 18
#define i18n_ncursesw_USE_BOLD_FOR_BRIGHT_FOREGROUND_COLORS 19
#define i18n_ncursesw_USE_BLINK_FOR_BRIGHT_BACKGROUND_COLORS 20
#define i18n_ncursesw_DONT_USE_COLORS 21
#define i18n_ncursesw_ENABLE_COLORS 22
#define i18n_ncursesw_NO_STORIES_REGISTERED_PLUS_HELP 23
#define i18n_ncursesw_SPACE_FOR_NEXT_PAGE 24
#define i18n_ncursesw_B_FOR_LAST_PAGE 25
#define i18n_ncursesw_USE_UMEM_FOR_SAVEGAMES 26
#define i18n_ncursesw_DISABLE_X11_GRAPHICS 27
#define i18n_ncursesw_USE_XTERM_TITLE 28
#define i18n_ncursesw_FORCE_8BIT_SOUND 29
#define i18n_ncursesw_DISABLE_SOUND 30
#define i18n_ncursesw_SET_TANDY_FLAG 31
#define i18n_ncursesw_DONT_UPDATE_STORY_LIST_ON_START 32
#define i18n_ncursesw_SEARCH_DIRECTORY 33
#define i18n_ncursesw_RECURSIVELY_SEARCH_DIRECTORY 34
#define i18n_ncursesw_START_GAME_WITH_RECORDING_COMMANDS 35
#define i18n_ncursesw_START_GAME_WITH_INPUT_FROM_FILE 36
#define i18n_ncursesw_UPDATE_STORY_LIST_ON_START 37
#define i18n_ncursesw_START_WITH_RANDOM_GENERATOR_IN_RANDOM_MODE 38
#define i18n_ncursesw_SYNC_TRANSCRIPT 39
#define i18n_ncursesw_FUNCTION_CALL_P0S_ABORTED_DUE_TO_ERROR 40
#define i18n_ncursesw_FUNCTION_CALL_P0S_RETURNED_ERROR_P1D_P2S 41
#define i18n_ncursesw_ERROR_P0D_OCCURED_BEFORE_READ_P1S 42
#define i18n_ncursesw_UNKNOWN_ERROR_CASE 43
#define i18n_ncursesw_FUNCTION_CALL_MALLOC_P2D_RETURNED_NULL_PROBABLY_OUT_OF_MEMORY 44
#define i18n_ncursesw_FIZMO_NCURSESW_VERSION_P0S 45
#define i18n_ncursesw_LIBCELLINTERFACE_VERSION_P0S 46
#define i18n_ncursesw_LOCALE_SEARCH_PATH 47
#define i18n_ncursesw_FILENAME_TO_READ_COMMANDS_FROM 48
#define i18n_ncursesw_ENABLE_X11_INLINE_GRAPHICS 49
#define i18n_ncursesw_LIBDRILBO_VERSION_P0S 50
#define i18n_ncursesw_DISABLE_HYPHENATION 51
#define i18n_ncursesw_SET_TRANSCRIPT_FILENAME 52
#define i18n_ncursesw_FILENAME_TO_RECORD_INPUT_TO 53
#define i18n_ncursesw_COULD_NOT_OPEN_OR_FIND_P0S 54
#define i18n_ncursesw_SET_NUMBER_OF_MAXIMUM_UNDO_STEPS 55

extern z_ucs fizmo_ncursesw_module_name[];

#endif // fizmo_ncursesw_locales_h_INCLUDED

==> fizmo-0.8.2.tar.gz: fizmo-0.8.2/fizmo-ncursesw/src/locales/fizmo_ncursesw_locales.h <==

/* fizmo_ncursesw_locales.h
 *
 * This file is part of fizmo.
 *
 * Copyright (c) 2009-2016 Christoph Ender.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef fizmo_ncursesw_locales_h_INCLUDED
#define fizmo_ncursesw_locales_h_INCLUDED

#define i18n_ncursesw_SET_FOREGROUND_COLOR 0
#define i18n_ncursesw_SET_BACKGROUND_COLOR 1
#define i18n_ncursesw_SET_LEFT_MARGIN_SIZE 2
#define i18n_ncursesw_SET_RIGHT_MARGIN_SIZE 3
#define i18n_ncursesw_INVALID_CONFIGURATION_VALUE_P0S_FOR_P1S 4
#define i18n_ncursesw_USAGE_DESCRIPTION 5
#define i18n_ncursesw_VALID_OPTIONS_ARE 6
#define i18n_ncursesw_SET_LOCALE_NAME_FOR_INTERPRETER_MESSAGES 7
#define i18n_ncursesw_START_WITH_RANDOM_GENERATOR_IN_PREDICTABLE_MODE 8
#define i18n_ncursesw_START_GAME_WITH_TRANSCRIPT_ENABLED 9
#define i18n_ncursesw_LIBFIZMO_VERSION_P0S 10 // no longer used.
#define i18n_ncursesw_LOCALES_AVAILIABLE 11
#define i18n_ncursesw_MORE_PROMPT 12
#define i18n_ncursesw_SCORE 13
#define i18n_ncursesw_TURNS 14
#define i18n_ncursesw_NUMBER_OF_COLOR_COMBINATIONS_AVAILABLE_P0D 15
#define i18n_ncursesw_COLORS_AVAILABLE 16
#define i18n_ncursesw_INVALID_COLOR_NAME 17
#define i18n_ncursesw_SHOW_HELP_MESSAGE_AND_EXIT 18
#define i18n_ncursesw_USE_BOLD_FOR_BRIGHT_FOREGROUND_COLORS 19
#define i18n_ncursesw_USE_BLINK_FOR_BRIGHT_BACKGROUND_COLORS 20
#define i18n_ncursesw_DONT_USE_COLORS 21
#define i18n_ncursesw_ENABLE_COLORS 22
#define i18n_ncursesw_NO_STORIES_REGISTERED_PLUS_HELP 23
#define i18n_ncursesw_SPACE_FOR_NEXT_PAGE 24
#define i18n_ncursesw_B_FOR_LAST_PAGE 25
#define i18n_ncursesw_USE_UMEM_FOR_SAVEGAMES 26
#define i18n_ncursesw_DISABLE_X11_GRAPHICS 27
#define i18n_ncursesw_USE_XTERM_TITLE 28
#define i18n_ncursesw_FORCE_8BIT_SOUND 29
#define i18n_ncursesw_DISABLE_SOUND 30
#define i18n_ncursesw_SET_TANDY_FLAG 31
#define i18n_ncursesw_DONT_UPDATE_STORY_LIST_ON_START 32
#define i18n_ncursesw_SEARCH_DIRECTORY 33
#define i18n_ncursesw_RECURSIVELY_SEARCH_DIRECTORY 34
#define i18n_ncursesw_START_GAME_WITH_RECORDING_COMMANDS 35
#define i18n_ncursesw_START_GAME_WITH_INPUT_FROM_FILE 36
#define i18n_ncursesw_UPDATE_STORY_LIST_ON_START 37
#define i18n_ncursesw_START_WITH_RANDOM_GENERATOR_IN_RANDOM_MODE 38
#define i18n_ncursesw_SYNC_TRANSCRIPT 39
#define i18n_ncursesw_FUNCTION_CALL_P0S_ABORTED_DUE_TO_ERROR 40
#define i18n_ncursesw_FUNCTION_CALL_P0S_RETURNED_ERROR_P1D_P2S 41
#define i18n_ncursesw_ERROR_P0D_OCCURED_BEFORE_READ_P1S 42
#define i18n_ncursesw_UNKNOWN_ERROR_CASE 43
#define i18n_ncursesw_FUNCTION_CALL_MALLOC_P2D_RETURNED_NULL_PROBABLY_OUT_OF_MEMORY 44
#define i18n_ncursesw_FIZMO_NCURSESW_VERSION_P0S 45
#define i18n_ncursesw_LIBMONOSPACEINTERFACE_VERSION_P0S 46
#define i18n_ncursesw_LOCALE_SEARCH_PATH 47
#define i18n_ncursesw_FILENAME_TO_READ_COMMANDS_FROM 48
#define i18n_ncursesw_ENABLE_X11_INLINE_GRAPHICS 49
#define i18n_ncursesw_LIBDRILBO_VERSION_P0S 50
#define i18n_ncursesw_DISABLE_HYPHENATION 51
#define i18n_ncursesw_SET_TRANSCRIPT_FILENAME 52
#define i18n_ncursesw_FILENAME_TO_RECORD_INPUT_TO 53
#define i18n_ncursesw_COULD_NOT_OPEN_OR_FIND_P0S 54
#define i18n_ncursesw_SET_NUMBER_OF_MAXIMUM_UNDO_STEPS 55

extern z_ucs fizmo_ncursesw_module_name[];

#endif // fizmo_ncursesw_locales_h_INCLUDED
